@@ -74,6 +74,8 @@ struct ini_cfgfile {
     int stats_read;
     /* Internal buffer */
     struct simplebuffer *file_data;
+    /* BOM indicator */
+    enum index_utf_t bom;
 };
 
 /* Parsing error */
@@ -99,6 +101,13 @@ int valid_collision_flags(uint32_t collision_flags);
 /* Empty section */
 int empty_section(struct collection_item *sec);
 
+/* Internal access check function */
+int access_check_int(struct stat *file_stats,
+                     uint32_t flags,
+                     uid_t uid,
+                     gid_t gid,
+                     mode_t mode,
+                     mode_t mask);
 
 
 #endif
