@@ -129,6 +129,29 @@
  */
 
 
+/**
+ * @defgroup bomType Types of configutration file encodings
+ *
+ * Constants that define how configuration file is encoded.
+ *
+ * @{
+ */
+/** Enumeration of the encoding types. */
+
+enum index_utf_t {
+    INDEX_UTF32BE = 0,  /**< The file is encoded in 'big-endian' 32-bit */
+    INDEX_UTF32LE = 1,  /**< The file is encoded in 'little-endian' 32-bit */
+    INDEX_UTF16BE = 2,  /**< The file is encoded in 'big-endian' 16-bit */
+    INDEX_UTF16LE = 3,  /**< The file is encoded in 'little-endian' 16-bit */
+    INDEX_UTF8 = 4,     /**< The file is encoded in standard UTF8 but has BOM */
+    INDEX_UTF8NOBOM = 5 /**< The file is encoded in standard UTF8 without BOM */
+};
+
+/**
+ * @}
+ */
+
+
 /**
  * @defgroup errorlevel Error tolerance constants
  *
@@ -370,6 +393,44 @@ enum INI_GET {
     INI_GET_LAST_VALUE   /**< Look for the last value in the section */
 };
 
+/**
+ * @}
+ */
+
+
+/**
+ * @defgroup augment Constants and structures related to augmentation.
+ *
+ * @{
+ */
+
+/** Structure to pass access check parameters to augmentation function.
+ *
+ */
+struct access_check {
+    uint32_t flags; /**< Define what to check.
+                     * One can check file
+                     * permissions with mask,
+                     * uid, and gid of the file.
+                     * See \ref accesscheck constants.
+                     */
+    uid_t uid;      /**< Expected uid of the file. */
+    gid_t gid;      /**< Expected gid of the file.*/
+    mode_t mode;    /**< Expected mode of the file. */
+    mode_t mask;    /**< Mask to use in the mode check.
+                     * Mask is always adjusted to
+                     * include at least S_IRWXU,
+                     * S_IRWXG and S_IRWXO.
+                     */
+};
+
+/** Enumeration of augmentation modes. */
+enum augmode {
+    INI_AUG_ANY   = 0, /**< Allow any augmentation. */
+    INI_AUG_ADD   = 1, /**< Allow only new sections. */
+    INI_AUG_OVER  = 2  /**< Allow section updates. */
+};
+
 /**
  * @}
  */
@@ -409,10 +470,8 @@ struct ini_parse_error;
  * parsing data from the configuration file and storing it in a configuration
  * object, merging configuration objects and other operations.
  *
- * This interface is currently incomplete as it does not allow:
- * - constructing configuration in memory
- * - altering existing configuration by adding, modifying or removing sections
- *   and keys.
+ * For functions to create or alter configuration object in memory
+ * see \ref ini_mod.
  *
  * @{
  *
@@ -547,6 +606,166 @@ int ini_config_file_reopen(struct ini_cfgfile *file_ctx_in,
  */
 void ini_config_file_destroy(struct ini_cfgfile *file_ctx);
 
+/**
+ * @brief Save configuration in a backup configuration file
+ *
+ * Creates a backup version of the data in a given configuration file.
+ * It is expected that file context was created by some open or reopen
+ * function first. Then the caller can make this call to save the data
+ * aside before parsing the configuration file and making changes to it.
+ *
+ * The caller can specify a backup directory to save the file in.
+ * If directory is not specified then a current working directory will
+ * be used. If the directory is invalid or caller does not have access to it
+ * an error will be returned.
+ *
+ *>The template specifies the file name to use for the backup.
+ *>For example:
+ *>    my_file.conf.%d.save
+ *>    my_file%d.conf.bak
+ *>The template can contain only one '%d' placeholder. This placeholder
+ * will be replaced by a number. If previously created backup files
+ * are found in the given directory. The function will start with 1 and will
+ * try to find an available unused file name in the given directory
+ * up until it reaches the limit specified in the max_num argument.
+ * Function will return EEXIST if it runs out of attempts to save the file.
+ *
+ * The caller can optionally pass an access structure. The access structure
+ * would specify what mode and ownership to use for the newly created file.
+ * If the access structure is not specified the access data of the original
+ * file context will be used. If file object does not have stats explicitly
+ * read at the time when the object is created then the stats will be collected
+ * but not saved. If the file was a memory mapped file and no access
+ * structure is passed in, the function will use effective UID and GID of the
+ * running process and mode will be set to: S_IFREG | S_IRUSR | S_IWUSR
+ *
+ * @param[in] file_ctx              File context of the file to backup.
+ * @param[in] backup_dir            Path to backup directory. Can be NULL.
+ * @param[in] backup_tpl            File name template with %d placeholder.
+ * @param[in] backup_access         Optional access overwrite structure.
+ *                                  See \ref access_check for more details.
+ * @param[in] max_num               Maximum number of retries to try to create
+ *                                  a specific backup file.
+ *
+ * @return 0 - Success.
+ * @return EINVAL - Invalid parameter.
+ * @return EIXIST - All possible backup file names are already taken.
+ * @return ENOMEM - No memory.
+ *
+ * Function can return other errors that standard libc functions line open,
+ * chmod, and chown return.
+ */
+int ini_config_file_backup(struct ini_cfgfile *file_ctx,
+                           const char *backup_dir,
+                           const char *backup_tpl,
+                           struct access_check *backup_access,
+                           unsigned max_num);
+
+/**
+ * @brief Change permissions and ownership of the file
+ *
+ * Function changes access mode and permissions of the file associated
+ * with the given context. If there is no file associated with the context
+ * because the context is created using a memory buffer, then the function
+ * will return an error EINVAL.
+ *
+ * @param[in] file_ctx              File context of the file to change access.
+ * @param[in] new_access            Structure that defines what access should
+ *                                  be set on the file.
+ *                                  See \ref access_check for more details.
+ *
+ * @return 0 - Success.
+ * @return EINVAL - Invalid parameter.
+ *
+ * Function can return other errors that standard chmod and chown
+ * functions return.
+ */
+int ini_config_change_access(struct ini_cfgfile *file_ctx,
+                             struct access_check *new_access);
+
+/**
+ * @brief Save configuration in a file
+ *
+ * Function is a wrapper around \ref ini_config_save_as with
+ * argument filename as NULL.
+ *
+ * For more information see \ref ini_config_save_as.
+ */
+int ini_config_save(struct ini_cfgfile *file_ctx,
+                    struct access_check *new_access,
+                    struct ini_cfgobj *ini_config);
+
+
+/* Save configuration in a file using existing context but with a new name */
+/**
+ * @brief Save configuration with a new name.
+ *
+ * Function uses an existing file context but a new file name.
+ * The file context will be used to perform operation to save file.
+ * By default the ownership, mode and BOM of the new file will be derived
+ * from the existing context. The rest of the context will be reinitialized.
+ * Configuration will be serialized and saved in the file using encoding
+ * specified by BOM type. The BOM prefix will also be added if needed.
+ * After saving the file the function initializes the context and reads the
+ * file back. At this moment the file context is ready for the parsing
+ * again.
+ *
+ * @param[in] file_ctx              File context to use for saving.
+ * @param[in] filename              Name of the file to save into. If NULL
+ *                                  the file name of the context will be used.
+ *                                  If the context was originally created
+ *                                  as a memory mapped configuration buffer
+ *                                  and filename is NULL the function will
+ *                                  return error EINVAL.
+ * @param[in] new_access            Structure that defines what access should
+ *                                  be set on the file.
+ *                                  See \ref access_check for more details.
+ * @param[in] ini_config            Configuration to save.
+ *
+ * @return 0 - Success.
+ * @return EINVAL - Invalid parameter.
+ *
+ * Function can return other errors that standard open, chmod and chown
+ * functions return.
+ */
+int ini_config_save_as(struct ini_cfgfile *file_ctx,
+                       const char *filename,
+                       struct access_check *new_access,
+                       struct ini_cfgobj *ini_config);
+
+
+
+/**
+ * @brief Return the encoding indicator.
+ *
+ * When the file object is created the configuration data is inspected for
+ * encoding indicator called BOM. This function returns a constant that
+ * indicates what type of BOM was detected.
+ *
+ * @param[in] file_ctx              File context.
+ *
+ * Function returns the constant of type enum index_utf_t.
+ */
+enum index_utf_t ini_config_get_bom(struct ini_cfgfile *file_ctx);
+
+/**
+ * @brief Set the encoding indicator.
+ *
+ * When the file object is created the configuration data is inspected for
+ * encoding indicator called BOM. The BOM indicator is recorded in the file
+ * object and used when the file is saved. If the caller wants to change
+ * the encoding before saving he can use this function to alter the BOM type.
+ *
+ * @param[in] file_ctx              File context.
+ * @param[in] bom                   BOM type indicator to set.
+ *
+ *
+ * @return 0 - Success.
+ * @return EINVAL - Invalid parameter.
+ */
+int ini_config_set_bom(struct ini_cfgfile *file_ctx, enum index_utf_t bom);
+
+
 /**
  * @brief Check parsing errors count
  *
@@ -780,6 +999,81 @@ int ini_config_merge(struct ini_cfgobj *first,
                      uint32_t collision_flags,
                      struct ini_cfgobj **result);
 
+
+/**
+ * @brief Augment configuration
+ *
+ * Function merges the main configuration file
+ * with the configuration file snippets
+ * read from a specified directory.
+ *
+ * @param[in]  base_cfg         A configuration object
+ *                              that will be augmented.
+ * @param[in]  path             Path to a directory where
+ *                              configuration snippets
+ *                              will be read from.
+ * @param[in]  patterns         List of regular expressions
+ *                              that the name of a snippet file
+ *                              has to match to be considered
+ *                              for merge.
+ * @param[in]  sections         List of regular expressions
+ *                              that the section names in the snippet
+ *                              file need to match. If file contains
+ *                              sections that do not match any patterns
+ *                              the file is skipped and error is recorded.
+ * @param[in]  check_perm       Pointer to structure that
+ *                              holds criteria for the
+ *                              access check.
+ * @param[in]  error_level      Flags that control actions
+ *                              in case of parsing error in a snippet file.
+ * @param[in]  collision_flags  These flags control how the potential
+ *                              collisions between keys and sections
+ *                              within the snippet file will be handled.
+ *                              For more information
+ *                              see collision flag definitions.
+ * @param[in]  parse_flags      Flags that control parsing process,
+ *                              for example how to handle spaces at
+ *                              the beginning of the line.
+ * @param[in]  merge_flags      Flags that control handling
+ *                              of the duplicate sections or keys
+ *                              during merging of the snippets.
+ *                              They are different from the collision flags
+ *                              because duplicate sections and keys inside
+ *                              are snippets most likely will be handled as
+ *                              'last value wins' while during merge
+ *                              the attempt to overwrite
+ *                              a specific section might be treated as
+ *                              an error.
+ * @param[out] result_cfg       A new configuration object,
+ *                              the result of the merge.
+ * @param[out] error_list       List of strings that
+ *                              contains all encountered
+ *                              errors.
+ *                              It can be NULL, in this case list of errors
+ *                              is not populated.
+ * @param[out] success_list     List of strings that
+ *                              contains file names of snippets that were
+ *                              successfully merged.
+ *                              It can be NULL, in this case list of files
+ *                              is not populated.
+ *
+ * @return 0 - Success.
+ * @return EINVAL - Invalid parameter.
+ * @return ENOMEM - No memory.
+ */
+int ini_config_augment(struct ini_cfgobj *base_cfg,
+                       const char *path,
+                       const char *patterns[],
+                       const char *sections[],
+                       struct access_check *check_perm,
+                       int error_level,
+                       uint32_t collision_flags,
+                       uint32_t parse_flags,
+                       uint32_t merge_flags,
+                       struct ini_cfgobj **result_cfg,
+                       struct ref_array **error_list,
+                       struct ref_array **success_list);
+
 /**
  * @brief Set the folding boundary
  *
@@ -814,8 +1108,8 @@ int ini_config_serialize(struct ini_cfgobj *ini_config,
                          struct simplebuffer *sbobj);
 
 
-/* TODO: Functions that add, modify or delete sections and values in
- * the configuration object.
+/* Functions that add, modify or delete sections and values in
+ * the configuration object can be found in section \ref ini_mod.
  */
 
 /**
