@@ -112,6 +112,14 @@ extern unsigned trace_level;
         } \
     } while(0)
 
+#define TRACE_RETURN(flow, val)      \
+    do { \
+        char mstr[200]; \
+        sprintf(mstr, "%s returning:", __FUNCTION__); \
+        flow(mstr, val); \
+    } while(0)
+
+
 /* Assertion */
 #define TRACE_ASSERT(expression) expression ? : printf("ASSERTION FAILED\n")
 #else /* HAVE_TRACE */
@@ -123,6 +131,8 @@ extern unsigned trace_level;
 #define TRACE_LNUMBER(level, msg, num)
 #define TRACE_SLNUMBER(level, msg, num)
 #define TRACE_DOUBLE(level, msg, num)
+#define TRACE_RETURN(flow, val)
+#define TRACE_ASSERT(expression)
 #endif /* HAVE_TRACE */
 
 
@@ -156,4 +166,10 @@ extern unsigned trace_level;
 #define TRACE_ERROR_DOUBLE(msg, num) TRACE_DOUBLE(TRACE_ERROR, msg, num)
 #define TRACE_INFO_DOUBLE(msg, num)  TRACE_DOUBLE(TRACE_INFO, msg, num)
 
+/* Some other nice wrappers for function entry and exit */
+#define TRACE_FLOW_ENTRY()          TRACE_FLOW_STRING(__FUNCTION__, "Entry")
+#define TRACE_FLOW_EXIT()           TRACE_FLOW_STRING(__FUNCTION__, "Exit")
+#define TRACE_FLOW_RETURN(val)      TRACE_RETURN(TRACE_FLOW_NUMBER, val)
+
+
 #endif /* COMMON_TRACE_H */
